summaryrefslogtreecommitdiffstats
path: root/src/Items
diff options
context:
space:
mode:
authorarchshift <admin@archshift.com>2014-07-19 11:51:39 +0200
committerarchshift <admin@archshift.com>2014-07-19 11:51:39 +0200
commitf5bcfdc58c7b5d69abbb222787bb2229c0b54088 (patch)
treeca52fbde3b744760e8dd9c1845d0ac7714a432ce /src/Items
parentFixed splash potion color on toss (diff)
downloadcuberite-f5bcfdc58c7b5d69abbb222787bb2229c0b54088.tar
cuberite-f5bcfdc58c7b5d69abbb222787bb2229c0b54088.tar.gz
cuberite-f5bcfdc58c7b5d69abbb222787bb2229c0b54088.tar.bz2
cuberite-f5bcfdc58c7b5d69abbb222787bb2229c0b54088.tar.lz
cuberite-f5bcfdc58c7b5d69abbb222787bb2229c0b54088.tar.xz
cuberite-f5bcfdc58c7b5d69abbb222787bb2229c0b54088.tar.zst
cuberite-f5bcfdc58c7b5d69abbb222787bb2229c0b54088.zip
Diffstat (limited to 'src/Items')
-rw-r--r--src/Items/ItemPotion.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/Items/ItemPotion.h b/src/Items/ItemPotion.h
index f3afbf99b..f16d89b39 100644
--- a/src/Items/ItemPotion.h
+++ b/src/Items/ItemPotion.h
@@ -17,8 +17,8 @@ public:
}
- /** Returns the potion particle type (used by the client for visuals), based on the potion's damage value */
- static int GetPotionParticleType(short a_ItemDamage)
+ /** Returns the potion color (used by the client for visuals), based on the potion's damage value */
+ static int GetPotionColor(short a_ItemDamage)
{
// Lowest six bits
return (a_ItemDamage & 0x3f);
@@ -156,7 +156,7 @@ public:
cSplashPotionEntity * Projectile = new cSplashPotionEntity(
a_Player, Pos.x, Pos.y, Pos.z, Speed,
GetEntityEffectType(PotionDamage), cEntityEffect(GetEntityEffectDuration(PotionDamage),
- GetEntityEffectIntensity(PotionDamage)), GetPotionParticleType(PotionDamage)
+ GetEntityEffectIntensity(PotionDamage)), GetPotionColor(PotionDamage)
);
if (Projectile == NULL)
{